class DownloadAllController < Hyrax::DownloadsController
  include HyraxHelper
  # include Hydra::Controller::DownloadBehavior
  include Hyrax::LocalFileDownloadsControllerBehavior

  # GET /download_all/1
  def show
    respond_to do |format|
      format.zip { send_zip }
      format.any { head :unsupported_media_type }
    end
  end

  def authorize_download!
    authorize! :download, params[:id]
  rescue CanCan::AccessDenied
    unauthorized_image = Rails.root.join("app", "assets", "images", "unauthorized.png")
    send_file unauthorized_image, status: :unauthorized
  end

  private

  def send_zip
    # if file_path should be same as zip_file_path
    file_path = download_bucket
    if file_path
      if File.exists?(zip_file) and local_file_last_modified < work.date_modified
        cleanup
        cleanup_zip
      end
      build_zip(file_path) unless File.exists?(zip_file)
      send_local_content
    else
      head :unsupported_media_type
    end
  end

  def download_bucket
    s3 = S3StorageService.new
    s3.init_client
    if within_file_size_threshold?(work)
      s3.download_bucket(work.id)
    else
      s3.prepare_csv_with_download_bucket_links(work.id)
    end
  end

  def work
    @work ||= ActiveFedora::Base.find(params[:id])
  end

  def file
    @file ||= zip_file
  end

  def work
    @work ||= ActiveFedora::Base.find(params[:id])
  end

  # Extend here to add other files to the zip
  def build_zip(file_path)
    zf = ZipFileGenerator.new(file_path, zip_file)
    zf.write
    cleanup
  end

  def cleanup
    FileUtils.rm_rf(zip_file_path)
  end

  def cleanup_zip
    FileUtils.rm_rf(zip_file)
  end

  def zip_file_path
    File.join(
      ENV.fetch('DOWNLOAD_PATH', "tmp/downloads"),
      file_name
    )
  end

  def file_name
    work.id
  end

  def zip_file
    "#{zip_file_path}.zip"
  end

  # Override from LocalFileDownloadsControllerBehavior
  def local_file_mime_type
    'application/zip'
  end

  # Override from LocalFileDownloadsControllerBehavior
  def local_file_name
    "#{file_name}.zip"
  end

  # Override from LocalFileDownloadsControllerBehavior
  def local_derivative_download_options
    super.merge(disposition: 'attachment')
  end

end
