# frozen_string_literal: true
module Hyrax
  # Presents a list of works in workflow
  class Admin::WorkflowsController < ApplicationController
    before_action :ensure_authorized!
    with_themed_layout 'dashboard'
    class_attribute :deposited_workflow_state_name, :archived_workflow_state_name

    # Works that are in this workflow state (see workflow json template) are excluded from the
    # status list and display in the "Published" tab
    self.deposited_workflow_state_name = 'published'

    def index
      add_breadcrumb t(:'hyrax.controls.home'), root_path
      add_breadcrumb t(:'hyrax.dashboard.breadcrumbs.admin'), hyrax.dashboard_path
      add_breadcrumb t(:'hyrax.admin.sidebar.tasks'), '#'
      add_breadcrumb t(:'hyrax.admin.sidebar.workflow_review'), request.path
      
      @status_list = actionable_objects.reject(&:published?).select{|object| under_review?(object.workflow_state) }
      @published_list = ActiveFedora::Base.where(workflow_state_name_ssim: 'published')
      @archived_list = ActiveFedora::Base.where(workflow_state_name_ssim: 'archived')
      @tombstoned_list = ActiveFedora::Base.where(is_tombstoned_ssim: 'true')
    end

    private

    def ensure_authorized!
      authorize! :review, :submissions
    end

    def actionable_objects
      @actionable_objects ||=
        Hyrax::Workflow::ActionableObjects.new(user: current_user)
    end

    def under_review?(workflow_state)
      ["pending_review_from_publication_manager","changes_required_from_publication_manager","pending_review_from_crc_manager","changes_required_from_crc_manager","pending_review_from_group_manager","changes_required_from_group_manager"].include?(workflow_state)
    end
  end
end