require 'rails_helper'
include Warden::Test::Helpers

RSpec.describe 'hyrax/crc_datasets/_attribute_rows', skip: true do
  # Create dataset calls s3. Need to stub that
  admin_role = Role.find_by(name: "admin")
  user = admin_role.users.first
  let(:partial) { 'hyrax/crc_datasets/attribute_rows' }
  let(:crc_dataset) { create(:crc_dataset, :open,  :with_folder_name, :with_experiment_description,
                             :with_complex_person, :with_crc_resource_type, :with_coverage, :with_approval_number,
                             :with_extra_information, :with_complex_subject, :with_complex_date, :with_modality,
                         :with_complex_identifier, :with_complex_funding_reference, :with_complex_relation) }
  let(:presenter) { Hyrax::CrcDatasetPresenter.new(SolrDocument.new(crc_dataset.to_solr), Ability.new(user), controller.request) }

  before do
    allow(controller).to receive(:current_user).and_return(user)
    login_as user if user.present?
    render partial: partial, locals: { presenter: presenter }
  end

  # NB: the visibility of individual metadata components is set in app/models/ability.rb
  # This test confirms the current expected behaviour (which is that most metadata is visible)

  context 'authenticated user' do
    it 'shows the correct metadata' do
      # experiment title
      expect(rendered).not_to have_content('Experiment title')
      # experiment description
      expect(rendered).not_to have_content('Experiment-Description-123')
      # complex person
      expect(rendered).to have_content('Anamika')
      expect(rendered).to have_content('operator')
      expect(rendered).to have_content('University')
      # crc resource type
      expect(rendered).to have_content('Simulated')
      # Coverage
      expect(rendered).to have_content('Bochum')
      # Approval number
      expect(rendered).to have_content('A1232')
      # Extra information
      expect(rendered).to have_content('Extra information')
      # complex subject
      expect(rendered).to have_content('s2312')
      expect(rendered).to have_content('Pigeons')
      expect(rendered).to have_content('Healthy control subject')
      expect(rendered).to have_content('female')
      expect(rendered).to have_content('18')
      # complex date
      expect(rendered).to have_content('Recorded')
      expect(rendered).to have_content('2022-10-28')
      # modality
      expect(rendered).to have_content('Behaviour')
      # doi
      expect(rendered).to have_content('1234-1567')
      # complex identifier
      expect(rendered).to have_content('doi:10.0.1111')
      # complex relation
      expect(rendered).to have_content('A relation label')
      expect(rendered).to have_content('is new version of')
      # complex funder reference
      expect(rendered).to have_content('f1234')
      expect(rendered).to have_content('Bank')
      expect(rendered).to have_content('a1234')
      expect(rendered).to have_content('http://example.com/a1234')
      expect(rendered).to have_content('No free lunch')
    end
  end
end
